@@ -1,6 +1,6 @@
-flm.ce.intspols <- function(d, formula, npf, t, n, dx, knotsx, pars, db, knotsb, v, nx,
-                      tol, dlbound, dubound, progress, nb, no.terms, no.ints, no.pols, 
-                        flinear, inter, ptm){
+flm.ce.intspols <- function(d, formula, npf, t, n, dx, knotsx, pars, db, knotsb, v, BI,  
+                      nx, tol, dlbound, dubound, progress, nb, no.terms, no.ints, no.pols, 
+                      flinear, inter, ptm){
   
   tu <- max(t)
   eps <- tol 
@@ -43,7 +43,8 @@ flm.ce.intspols <- function(d, formula, npf, t, n, dx, knotsx, pars, db, knotsb,
     dxpols.coord <- which(dx.pols > 0)
     allknotsxb <- replicate(dx.pols[dxpols.coord], unlist(knotsx[dxpols.coord]), simplify=FALSE)
     nx.ints <- rep(nx[dxpols.coord], dx.pols[dxpols.coord])
-    if ((prod(nx.ints)<nb[h]) & (identical(flinear, linearcpp.aopt))) stop("For A-optimality, the product of basis functions for the profile factors involved in a polynomial must be greater or equal to the number of basis functions for the parameter")
+    if ((prod(nx.ints)<nb[h]) & (identical(flinear, linearcpp.aopt))) stop("For SE loss, the product of basis functions for the profile factors involved in a polynomial must be greater or equal to the number of basis functions for the parameter")
+    if ((prod(nx.ints)<nb[h]) & (identical(flinear, linearcpp.aopt.weighted))) stop("For WSE loss, the product of basis functions for the profile factors involved in a polynomial must be greater or equal to the number of basis functions for the parameter")
     lkxi <- length(allknotsxb)
     lnxvec <- list()
     for (u in 1:lkxi) {
@@ -66,7 +67,8 @@ flm.ce.intspols <- function(d, formula, npf, t, n, dx, knotsx, pars, db, knotsb,
       dx.ints <- modframe.intspols[,q]
       allknotsxb <- knotsx[dx.ints==1]
       nx.ints <- nx[dx.ints==1]
-      if ((prod(nx.ints) < nb[q]) & (identical(flinear, linearcpp.aopt))) stop("For A-optimality, the product of basis functions for the profile factors involved in an interaction must be greater or equal to the number of basis functions for the parameter")
+      if ((prod(nx.ints) < nb[q]) & (identical(flinear, linearcpp.aopt))) stop("For SE loss, the product of basis functions for the profile factors involved in an interaction must be greater or equal to the number of basis functions for the parameter")
+      if ((prod(nx.ints) < nb[q]) & (identical(flinear, linearcpp.aopt.weighted))) stop("For WSE loss, the product of basis functions for the profile factors involved in an interaction must be greater or equal to the number of basis functions for the parameter")
       lkxi <- length(allknotsxb)
       lnxvec <- list()
       for (m in 1:lkxi) {
@@ -88,7 +90,7 @@ flm.ce.intspols <- function(d, formula, npf, t, n, dx, knotsx, pars, db, knotsb,
   } else {
     z <- djmat
   }
-  curr.eval <- flinear(z=z, v=v) 
+  curr.eval <- flinear(z=z, v=v, b=BI) 
   it <- 1
   if (progress == TRUE) {
     cat("Starting design", c("( Current Value =", curr.eval,")"), "\n")
@@ -113,7 +115,7 @@ flm.ce.intspols <- function(d, formula, npf, t, n, dx, knotsx, pars, db, knotsb,
             } else {
               zopt <- mlist(f,jmat)
             }
-            result <- flinear(z=zopt, v=v)
+            result <- flinear(z=zopt, v=v, b=BI)
             result
           }
           d[[p]][i,j] <- optim(par=d[[p]][i,j], fn=fnobj, lower=dlbound, 
@@ -134,7 +136,7 @@ flm.ce.intspols <- function(d, formula, npf, t, n, dx, knotsx, pars, db, knotsb,
     } else {
       z <- mlist(d,jmat)
     }
-    final.opt <- flinear(z=z, v=v)
+    final.opt <- flinear(z=z, v=v, b=BI)
     diff <- abs(curr.eval - final.opt)
     curr.eval <- final.opt
     
